$ = django.jQuery;
$.fn.reverse = [].reverse;

// hide images that fail to load
document.querySelector('body').addEventListener('error', function (e) {
    e.target.style.opacity = 0;
}, true)

// setup timezone
{% get_current_timezone as TIME_ZONE %}
window.TIME_ZONE = '{{TIME_ZONE}}'

window.setCookie = function(name, value, days) {
    let expires = ""
    if (days) {
        const date = new Date()
        date.setTime(date.getTime() + (days*24*60*60*1000))
        expires = "; expires=" + date.toUTCString()
    }
    document.cookie = name + "=" + (value || "")  + expires + "; path=/"
}

function setTimeOffset() {
    if (window.GMT_OFFSET) return
    window.GMT_OFFSET = -(new Date).getTimezoneOffset()
    window.setCookie('GMT_OFFSET', window.GMT_OFFSET, 365)
}

// change the admin actions button from a dropdown to buttons across
function fix_actions() {
    const container = $('div.actions')

    // too many actions to turn into buttons
    if (container.find('select[name=action] option').length >= 11) return

    // hide the empty default option thats just a placeholder with no value
    container.find('label:nth-child(1), button[value=0]').hide()

    const buttons = $('<div></div>')
        .insertAfter('div.actions button[type=submit]')
        .css('display', 'inline')
        .addClass('class', 'action-buttons');

    // for each action in the dropdown, turn it into a button instead
    container.find('select[name=action] option:gt(0)').each(function () {
        const action_type = this.value
        $('<button>')
            .attr('type', 'button')
            .attr('name', action_type)
            .addClass('button')
            .text(this.text)
            .click(function (e) {
                e.preventDefault()
                e.stopPropagation()

                const num_selected = document.querySelector('.action-counter').innerText.split(' ')[0]

                if (action_type === 'overwrite_snapshots') {
                    const message = (
                        'Are you sure you want to re-archive (overwrite) ' + num_selected + ' Snapshots?\n\n' +
                        'This will delete all previously saved files from these Snapshots and re-archive them from scratch.\n\n'
                    )
                    if (!window.confirm(message)) return false
                }
                if (action_type === 'delete_snapshots') {
                    const message = (
                        'Are you sure you want to permanently delete ' + num_selected + ' Snapshots?\n\n' +
                        'They will be removed from your index, and all their Snapshot content on disk will be permanently deleted.'
                    )
                    if (!window.confirm(message)) return false
                }

                // select the action button from the dropdown
                container.find('select[name=action]')
                    .find('[selected]').removeAttr('selected').end()
                    .find('[value=' + action_type + ']').attr('selected', 'selected').click()

                // click submit & replace the archivebox logo with a spinner
                $('#changelist-form button[name="index"]').click()
                document.querySelector('#logo').outerHTML = '<div class="loader"></div>'
                return false
            })
            .appendTo(buttons)
    })
    console.log('Converted', buttons.children().length, 'admin actions from dropdown to buttons')
}

function setupSnapshotGridListToggle() {
    $("#snapshot-view-list").click(selectSnapshotListView)
    $("#snapshot-view-grid").click(selectSnapshotGridView)

    $('#changelist-form .card input:checkbox').change(function() {
        if ($(this).is(':checked'))
            $(this).parents('.card').addClass('selected-card')
        else
            $(this).parents('.card').removeClass('selected-card')
    })
};
$(document).ready(function() {
    fix_actions()
    setupSnapshotGridListToggle()
    setTimeOffset()
})
